@@ -12,6 +12,7 @@ type Target struct {
 	Projects []string `yaml:"projects"`
 	Paths    []string `yaml:"paths"`
 	Tags     []string `yaml:"tags"`
+	TagsExpr string   `yaml:"tags_expr"`
 	Cwd      bool     `yaml:"cwd"`
 
 	context     string
@@ -48,6 +49,18 @@ func (c *Config) GetTargetList() ([]Target, []ResourceErrors[Target]) {
 			continue
 		}
 
+		if target.TagsExpr != "" {
+			valid := validateExpression(target.TagsExpr)
+			if valid != nil {
+				foundErrors = true
+				targetError := ResourceErrors[Target]{
+					Resource: target,
+					Errors:   []error{&core.TargetTagsExprError{Name: target.Name, Err: valid}},
+				}
+				targetErrors = append(targetErrors, targetError)
+			}
+		}
+
 		targets = append(targets, *target)
 	}
 
